diff --git a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/src/BCM_RDO_ContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/src/BCM_RDO_ContainerCnv.cxx
index 70c5f2844853544b2020044b59a95b87220d64ef..2a8f1be4e435db72ee931baf7910f5c415ba55a6 100755
--- a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/src/BCM_RDO_ContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/src/BCM_RDO_ContainerCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 // Pool converter for BCM_RDO_Container
@@ -21,7 +21,7 @@ BCM_RDO_Container_p0* BCM_RDO_ContainerCnv::createPersistent(BCM_RDO_Container*
 BCM_RDO_Container* BCM_RDO_ContainerCnv::createTransient() {
   MsgStream log(msgSvc(), "BCM_RDO_ContainerCnv");
   if (log.level()<=MSG::DEBUG) log << MSG::DEBUG << "In BCM_RDO_ContainerCnv::createTransient" << endmsg;
-  std::auto_ptr<BCM_RDO_Container_p0> persCont(poolReadObject<BCM_RDO_Container_p0>());
+  std::unique_ptr<BCM_RDO_Container_p0> persCont(poolReadObject<BCM_RDO_Container_p0>());
   BCM_RDO_Container* transCont = m_Converter.createTransient(persCont.get(),log);
   if (log.level()<=MSG::DEBUG) log << MSG::DEBUG << "Made transient BCM RDO Container with " << transCont->size() << " entries" << endmsg;
   return transCont;
diff --git a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_CollectionCnv_p0_test.cxx b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_CollectionCnv_p0_test.cxx
index beddfe431b281bf101f2e7003e136c4822216185..a0a3680a65624bf2b91658c3517ffd0650642fc0 100644
--- a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_CollectionCnv_p0_test.cxx
+++ b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_CollectionCnv_p0_test.cxx
@@ -56,7 +56,7 @@ void test1()
   BCM_RDO_Collection trans1 (543);
   for (int i=0; i < 10; i++) {
     int o = i*100;
-    trans1.push_back (new BCM_RawData (123+o, 234+o));
+    trans1.push_back (std::make_unique<BCM_RawData> (123+o, 234+o));
   }
     
   testit (trans1);
diff --git a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_ContainerCnv_p0_test.cxx b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_ContainerCnv_p0_test.cxx
index f019ab8d9d438eb669d0624e54beed9574a6b1d4..60ad67f013e59a8a7197555d78eb003d8e88e006 100644
--- a/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_ContainerCnv_p0_test.cxx
+++ b/InnerDetector/InDetEventCnv/InDetBCM_EventAthenaPool/test/BCM_RDO_ContainerCnv_p0_test.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 // $Id$
@@ -70,7 +70,7 @@ void test1()
     auto coll = CxxUtils::make_unique<BCM_RDO_Collection> (543+o1);
     for (int j=0; j<i; j++) {
       int o2 = o1 + j*20;
-      coll->push_back (new BCM_RawData (123+o2, 234+o2));
+      coll->push_back (std::make_unique<BCM_RawData> (123+o2, 234+o2));
     }
     trans1.push_back (std::move(coll));
   }
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaCandidateCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaCandidateCnv.cxx
index 8979a60dfe06bb3766753b2599873eaed6fb7926..3c183bd43463ba3c118968c61266b59e762085f3 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaCandidateCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaCandidateCnv.cxx
@@ -28,7 +28,7 @@ InDetLowBetaCandidate_PERS* InDetLowBetaCandidateCnv::createPersistent(InDet::In
 InDet::InDetLowBetaCandidate* InDetLowBetaCandidateCnv::createTransient() {
   ATH_MSG_DEBUG("InDetLowBetaCandidateCnv::createTransient ");
   
-  const pool::Guid tlp1_guid("8C24589F-FBAA-4686-9254-B5C360A94733");
+  static const pool::Guid tlp1_guid("8C24589F-FBAA-4686-9254-B5C360A94733");
 
   InDet::InDetLowBetaCandidate *trans_cont(0);
   
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaContainerCnv.cxx
index 5935d17948eb72acab95747dcc259ad65da31cf2..cd92cb551649f64b1df871dfffb21daaf52be632 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetLowBetaContainerCnv.cxx
@@ -30,7 +30,7 @@ InDetLowBetaContainer_PERS *InDetLowBetaContainerCnv::createPersistent(InDet::In
 InDet::InDetLowBetaContainer *InDetLowBetaContainerCnv::createTransient() {
   ATH_MSG_DEBUG("InDetLowBetaContainerCnv::createTransient called");
 
-  const pool::Guid tlp1_guid("2EBE2034-8157-477B-B327-D37BE8A0317D");
+  static const pool::Guid tlp1_guid("2EBE2034-8157-477B-B327-D37BE8A0317D");
 
   InDet::InDetLowBetaContainer *p_collection = 0;
   if (compareClassGuid(tlp1_guid)) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetSimDataCollectionCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetSimDataCollectionCnv.cxx
index aaa95ca0363bb497236024d910cdedc7e52f2288..364f477ff0a8e13522a2bdc5a45566815508f386 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetSimDataCollectionCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetSimDataCollectionCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimDataCollectionCnv.h"
@@ -20,13 +20,13 @@ InDetSimDataCollection* InDetSimDataCollectionCnv::createTransient() {
     InDetSimDataCollectionCnv_p3   converter_p3;
 
     InDetSimDataCollection       *trans_cont(0);
-    const pool::Guid   p3_guid("1430AA7B-EE92-5A41-92F3-5DD5367D6BAA");
-    const pool::Guid   p2_guid("C648CA66-013D-44AC-B0D9-99BFB0060E84");
-    const pool::Guid   p1_guid("333EF996-1672-4AB8-917D-187F908F1EDE");
-    const pool::Guid   old_guid("5A50C32E-C036-4A49-AE97-716D53210BE1");
+    static const pool::Guid   p3_guid("1430AA7B-EE92-5A41-92F3-5DD5367D6BAA");
+    static const pool::Guid   p2_guid("C648CA66-013D-44AC-B0D9-99BFB0060E84");
+    static const pool::Guid   p1_guid("333EF996-1672-4AB8-917D-187F908F1EDE");
+    static const pool::Guid   old_guid("5A50C32E-C036-4A49-AE97-716D53210BE1");
 
     if( this->compareClassGuid(p3_guid)) {
-        std::auto_ptr< InDetSimDataCollection_p3 >   col_vect( this->poolReadObject< InDetSimDataCollection_p3 >() );
+        std::unique_ptr< InDetSimDataCollection_p3 >   col_vect( this->poolReadObject< InDetSimDataCollection_p3 >() );
         trans_cont = converter_p3.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p2_guid)) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetTrackCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetTrackCnv.cxx
index 678a345f52f68ef2d89d792c430cba395f96b06c..4645029cb10973c6f28b4f254bd6d82475f1e0ba 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetTrackCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/InDetTrackCnv.cxx
@@ -32,8 +32,8 @@ StatusCode InDetTrackCnv::initialize()
 void 
 InDetTrackCnv::readObjectFromPool( const std::string& token )
 {
-    const pool::Guid p2_guid( "4E3778E2-1497-4F10-8746-AA02319FAC83" );
-    const pool::Guid p1_guid( "8380F7AC-4A8F-4382-95A5-1234E43D3B08" );
+    static const pool::Guid p2_guid( "4E3778E2-1497-4F10-8746-AA02319FAC83" );
+    static const pool::Guid p1_guid( "8380F7AC-4A8F-4382-95A5-1234E43D3B08" );
 
    // set the POOL token which will be used for reading from POOL
    setToken( token );
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p1.cxx
index a7ad42405c5bf2e60ae4c3215c8e34d57fc688d0..be55c15e7a038d4c64b4e71997c19d8968d2a2f4 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p1.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetRawData/Pixel1RawData.h"
@@ -126,7 +126,7 @@ void  Pixel1RawDataContainerCnv_p1::persToTrans(const InDetRawDataContainer_p1*
 
 //================================================================
 PixelRDO_Container* Pixel1RawDataContainerCnv_p1::createTransient(const InDetRawDataContainer_p1* persObj, MsgStream& log) {
-    std::unique_ptr<PixelRDO_Container> trans(new PixelRDO_Container(m_pixId->wafer_hash_max()));
+    std::unique_ptr<PixelRDO_Container> trans(std::make_unique<PixelRDO_Container>(m_pixId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p2.cxx
index 87d4f8ec8466b2cc7a1736378afb0d7a777bf517..f9bd07779b81e6e4c9784490c0863f09523a00f2 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/Pixel1RawDataContainerCnv_p2.cxx
@@ -128,7 +128,7 @@ void  Pixel1RawDataContainerCnv_p2::persToTrans(const InDetRawDataContainer_p2*
 
 //================================================================
 PixelRDO_Container* Pixel1RawDataContainerCnv_p2::createTransient(const InDetRawDataContainer_p2* persObj, MsgStream& log) {
-    std::unique_ptr<PixelRDO_Container> trans(new PixelRDO_Container(m_pixId->wafer_hash_max()));
+    std::unique_ptr<PixelRDO_Container> trans(std::make_unique<PixelRDO_Container>(m_pixId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv.cxx
index f3bc60d9f8258c0516eca3c4bf1b587fa7af57ac..a86f592cab7e9248a4fb71414b492ec9e3183467 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "StoreGate/StoreGateSvc.h"
@@ -66,10 +66,10 @@ StatusCode PixelClusterContainerCnv::initialize() {
 
 
 InDet::PixelClusterContainer* PixelClusterContainerCnv::createTransient() {
-  const pool::Guid   p0_guid("37B00A31-EA80-45DF-9A3F-2721EC0F0DA6"); // before t/p split
-  const pool::Guid   p1_guid("9DB54746-8C4E-4A56-8B4C-0E5D42905218"); // with PixelCluster_tlp1
-  const pool::Guid   p2_guid("DE48E26B-9E03-4EAD-86B9-351AD88D060E"); // with pixelCluster_p2
-  const pool::Guid   p3_guid("7BF0F163-B227-434C-86A6-16130E005E6C"); // with pixelCluster_p3
+  static const pool::Guid   p0_guid("37B00A31-EA80-45DF-9A3F-2721EC0F0DA6"); // before t/p split
+  static const pool::Guid   p1_guid("9DB54746-8C4E-4A56-8B4C-0E5D42905218"); // with PixelCluster_tlp1
+  static const pool::Guid   p2_guid("DE48E26B-9E03-4EAD-86B9-351AD88D060E"); // with pixelCluster_p2
+  static const pool::Guid   p3_guid("7BF0F163-B227-434C-86A6-16130E005E6C"); // with pixelCluster_p3
   ATH_MSG_DEBUG("createTransient(): main converter");
   InDet::PixelClusterContainer* p_collection(0);
   if( compareClassGuid(p3_guid) ) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv_p0.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv_p0.cxx
index 1fdef16f373e4295cd2c71ea7e5fd32d5c00f5d6..9c931a41ce93a66eb5d58bf73b00974de1ab3fe0 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv_p0.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelClusterContainerCnv_p0.cxx
@@ -47,7 +47,7 @@ StatusCode PixelClusterContainerCnv_p0::initialize(MsgStream &log ) {
 
 InDet::PixelClusterContainer* PixelClusterContainerCnv_p0::createTransient(PixelClusterContainer_p0* persObj, MsgStream& log) {
 
-  std::unique_ptr<InDet::PixelClusterContainer> trans(new InDet::PixelClusterContainer(m_pixId->wafer_hash_max()) );
+  std::unique_ptr<InDet::PixelClusterContainer> trans(std::make_unique<InDet::PixelClusterContainer>(m_pixId->wafer_hash_max()) );
   MSG_DEBUG(log,"Read PRD vector, size " << persObj->size());
 
   for (InDet::PixelClusterCollection* dcColl : *persObj) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelGangedClusterAmbiguitiesCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelGangedClusterAmbiguitiesCnv.cxx
index 26699ff884359890ab08cfc87051302f97df50da..5007998f915fc1ddba1fc31e95b7c63ef368bd3a 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelGangedClusterAmbiguitiesCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelGangedClusterAmbiguitiesCnv.cxx
@@ -19,8 +19,8 @@ PixelGangedClusterAmbiguities_PERS* PixelGangedClusterAmbiguitiesCnv::createPers
 }
     
 InDet::PixelGangedClusterAmbiguities* PixelGangedClusterAmbiguitiesCnv::createTransient() {
-    const pool::Guid   p1_guid("FE36CE7E-EADF-481F-A55A-26DA0030DFAA");
-//     const pool::Guid   p0_guid("380D8BB9-B34F-470F-92CC-06C3D60F7BE4");
+    static const pool::Guid   p1_guid("FE36CE7E-EADF-481F-A55A-26DA0030DFAA");
+//     static const pool::Guid   p0_guid("380D8BB9-B34F-470F-92CC-06C3D60F7BE4");
     if( compareClassGuid(p1_guid) ) {
         // using unique_ptr ensures deletion of the persistent object
         std::unique_ptr< InDet::PixelGangedClusterAmbiguities_p1 > col_vect( poolReadObject< InDet::PixelGangedClusterAmbiguities_p1 >() );
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv.cxx
index 8b4d6fe941c42d13d49215ae1da3c317b0892668..0c234e4a47b0926a0077047a98ea096a7bafec05 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "PixelRDO_ContainerCnv.h"
@@ -123,9 +123,9 @@ PixelRDO_Container_PERS* PixelRDO_ContainerCnv::createPersistent(PixelRDO_Contai
 //================================================================
 PixelRDO_Container* PixelRDO_ContainerCnv::createTransient() {
 
-  const pool::Guid   p0_guid("7F2C09B6-0B47-4957-8BBA-EDC665A290AC"); // with Pixel1RawData
-  const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
-  const pool::Guid   TP2_guid("7138342E-0A80-4A32-A387-2842A01C2539"); // for t/p separated version with InDetRawDataContainer_p2
+  static const pool::Guid   p0_guid("7F2C09B6-0B47-4957-8BBA-EDC665A290AC"); // with Pixel1RawData
+  static const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
+  static const pool::Guid   TP2_guid("7138342E-0A80-4A32-A387-2842A01C2539"); // for t/p separated version with InDetRawDataContainer_p2
   ATH_MSG_DEBUG("createTransient(): main converter");
 
   if( compareClassGuid(TP2_guid) ) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv_p0.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv_p0.cxx
index 4a78e1b9a51794d7ab932552e8dc2f3bab5b1c26..502b89df8546d52eaae5e529525821f4afe24a65 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv_p0.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/PixelRDO_ContainerCnv_p0.cxx
@@ -17,7 +17,7 @@
 
 //================================================================
 PixelRDO_Container* PixelRDO_ContainerCnv_p0::createTransient(const PixelRDO_Container_p0* persObj, MsgStream& log) {
-  std::unique_ptr<PixelRDO_Container> trans(new PixelRDO_Container(m_pixId->wafer_hash_max()));
+  std::unique_ptr<PixelRDO_Container> trans(std::make_unique<PixelRDO_Container>(m_pixId->wafer_hash_max()));
 
   MSG_DEBUG(log,"Read RDO vector, size " << persObj->size());
   
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_ClusterContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_ClusterContainerCnv.cxx
index 4ce7fb35838d467cc92dfcbc13cbccb008195bde..4027cfeabd1818e9eff5b91e7a440b40cbd6ad16 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_ClusterContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_ClusterContainerCnv.cxx
@@ -69,10 +69,10 @@ StatusCode SCT_ClusterContainerCnv::initialize() {
 
 InDet::SCT_ClusterContainer* SCT_ClusterContainerCnv::createTransient() {
   //  MsgStream log(msgSvc(), "SCT_ClusterContainerCnv" );
-  const pool::Guid   p0_guid("A180F372-0D52-49C3-8AA0-0939CB0B8179"); // before t/p split
-  const pool::Guid   p1_guid("657F6546-F5CD-4166-9567-16AD9C96D286"); // with SCT_Cluster_tlp1
-  const pool::Guid   p2_guid("ECE7D831-0F31-4E6F-A6BE-2ADDE90083BA"); // with SCT_Cluster_p2
-  const pool::Guid   p3_guid("623F5836-369F-4A94-9DD4-DAD728E93C13"); // with SCT_Cluster_p3
+  static const pool::Guid   p0_guid("A180F372-0D52-49C3-8AA0-0939CB0B8179"); // before t/p split
+  static const pool::Guid   p1_guid("657F6546-F5CD-4166-9567-16AD9C96D286"); // with SCT_Cluster_tlp1
+  static const pool::Guid   p2_guid("ECE7D831-0F31-4E6F-A6BE-2ADDE90083BA"); // with SCT_Cluster_p2
+  static const pool::Guid   p3_guid("623F5836-369F-4A94-9DD4-DAD728E93C13"); // with SCT_Cluster_p3
 
   //ATH_MSG_DEBUG("createTransient(): main converter");
   InDet::SCT_ClusterContainer* p_collection(nullptr);
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_RDO_ContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_RDO_ContainerCnv.cxx
index 0cb8a6592c1e28173c571794d2129f1470c4e686..c7bc62d85e919f84d8de9b516cc128d54dce5c00 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_RDO_ContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_RDO_ContainerCnv.cxx
@@ -143,12 +143,12 @@ SCT_RDO_Container_PERS* SCT_RDO_ContainerCnv::createPersistent(SCT_RDO_Container
 //================================================================
 SCT_RDO_Container* SCT_RDO_ContainerCnv::createTransient() {
 
-  const pool::Guid   p0_guid("B82A1D11-3F86-4F07-B380-B61BA2DAF3A9"); // with SCT1_RawData
-  const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
-  const pool::Guid   SCT_TP1_guid("8E13963E-13E5-4D10-AA8B-73F00AFF8FA8"); // for t/p separated version with SCT_RawDataContainer_p1
-  const pool::Guid   SCT_TP2_guid("D1258125-2CBA-476E-8578-E09D54F477E1"); // for t/p separated version with SCT_RawDataContainer_p2
-  const pool::Guid   SCT_TP3_guid("5FBC8D4D-7B4D-433A-8487-0EA0C870CBDB"); // for t/p separated version with SCT_RawDataContainer_p3
-  const pool::Guid   SCT_TP4_guid("6C7540BE-E85C-4777-BC1C-A9FF11460F54"); // for t/p separated version with SCT_RawDataContainer_p4
+  static const pool::Guid   p0_guid("B82A1D11-3F86-4F07-B380-B61BA2DAF3A9"); // with SCT1_RawData
+  static const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
+  static const pool::Guid   SCT_TP1_guid("8E13963E-13E5-4D10-AA8B-73F00AFF8FA8"); // for t/p separated version with SCT_RawDataContainer_p1
+  static const pool::Guid   SCT_TP2_guid("D1258125-2CBA-476E-8578-E09D54F477E1"); // for t/p separated version with SCT_RawDataContainer_p2
+  static const pool::Guid   SCT_TP3_guid("5FBC8D4D-7B4D-433A-8487-0EA0C870CBDB"); // for t/p separated version with SCT_RawDataContainer_p3
+  static const pool::Guid   SCT_TP4_guid("6C7540BE-E85C-4777-BC1C-A9FF11460F54"); // for t/p separated version with SCT_RawDataContainer_p4
 
 #ifdef SCT_DEBUG
   ATH_MSG_DEBUG("createTransient(): main converter");
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv.cxx
index 986cdee679239d4a18276252a31eb0cbd642e64e..5fcbdd78f0a5e2b431bd890dfcb286f9d7fcee06 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "TRT_DriftCircleContainerCnv.h"
@@ -66,9 +66,9 @@ StatusCode TRT_DriftCircleContainerCnv::initialize() {
 
 InDet::TRT_DriftCircleContainer* TRT_DriftCircleContainerCnv::createTransient() {
 
-  const pool::Guid   p0_guid("A99630C5-3D7C-4DB4-9E6C-FC3CEF981895"); // before t/p split
-  const pool::Guid   p1_guid("42B48D79-AF4E-4D45-AAA9-A2BA5A033534"); // with TRT_DriftCircle_tlp1
-  const pool::Guid   p2_guid("36195EDE-941C-424B-81A1-E04C867C35D8"); // with TRT_DriftCircle_p2
+  static const pool::Guid   p0_guid("A99630C5-3D7C-4DB4-9E6C-FC3CEF981895"); // before t/p split
+  static const pool::Guid   p1_guid("42B48D79-AF4E-4D45-AAA9-A2BA5A033534"); // with TRT_DriftCircle_tlp1
+  static const pool::Guid   p2_guid("36195EDE-941C-424B-81A1-E04C867C35D8"); // with TRT_DriftCircle_p2
   ATH_MSG_DEBUG("createTransient(): main converter");
   InDet::TRT_DriftCircleContainer* p_collection(0);
   if( compareClassGuid(p2_guid) ) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv_p0.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv_p0.cxx
index d9d0e50edaaa5c9bc4165d900716b994d4f5b815..7105c4bc63f2f24ea656881aa3c52783f8c982c8 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv_p0.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_DriftCircleContainerCnv_p0.cxx
@@ -43,7 +43,7 @@ StatusCode TRT_DriftCircleContainerCnv_p0::initialize(MsgStream &log ) {
 
 InDet::TRT_DriftCircleContainer* TRT_DriftCircleContainerCnv_p0::createTransient(TRT_DriftCircleContainer_p0* persObj, MsgStream& log) {
 
-  std::unique_ptr<InDet::TRT_DriftCircleContainer> trans(new InDet::TRT_DriftCircleContainer(m_trtId->straw_layer_hash_max()) );
+  std::unique_ptr<InDet::TRT_DriftCircleContainer> trans(std::make_unique<InDet::TRT_DriftCircleContainer>(m_trtId->straw_layer_hash_max()) );
   MSG_DEBUG(log,"Read PRD vector, size " << persObj->size());
   
   for (InDet::TRT_DriftCircleCollection* dcColl : *persObj) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p1.cxx
index c6ba6ac2aaac3a206621c57f90da0bcb31f51294..b0f88bc7a8fe3b78a62e7034f4385d732da46bf0 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p1.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetRawData/TRT_LoLumRawData.h"
@@ -126,7 +126,7 @@ void  TRT_LoLumRawDataContainerCnv_p1::persToTrans(const InDetRawDataContainer_p
 
 //================================================================
 TRT_RDO_Container* TRT_LoLumRawDataContainerCnv_p1::createTransient(const InDetRawDataContainer_p1* persObj, MsgStream& log) {
-    std::unique_ptr<TRT_RDO_Container> trans(new TRT_RDO_Container(m_trtId->straw_layer_hash_max()));
+    std::unique_ptr<TRT_RDO_Container> trans(std::make_unique<TRT_RDO_Container>(m_trtId->straw_layer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p2.cxx
index 6e00bc2cc95915e903de6e02ca6a4fb5f80cfe2b..0a06bfda6f601a90b7a6dc123985a3da465b62c7 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_LoLumRawDataContainerCnv_p2.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetRawData/TRT_LoLumRawData.h"
@@ -127,7 +127,7 @@ void  TRT_LoLumRawDataContainerCnv_p2::persToTrans(const InDetRawDataContainer_p
 
 //================================================================
 TRT_RDO_Container* TRT_LoLumRawDataContainerCnv_p2::createTransient(const InDetRawDataContainer_p2* persObj, MsgStream& log) {
-    std::unique_ptr<TRT_RDO_Container> trans(new TRT_RDO_Container(m_trtId->straw_layer_hash_max()));
+    std::unique_ptr<TRT_RDO_Container> trans(std::make_unique<TRT_RDO_Container>(m_trtId->straw_layer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv.cxx
index 0777c67596b82c3acd82aedab51ad1f9dcfa6673..3b2c9d76bfc8ed4a2c95c8785eb1e28197d46082 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "TRT_RDO_ContainerCnv.h"
@@ -122,10 +122,10 @@ TRT_RDO_Container_PERS* TRT_RDO_ContainerCnv::createPersistent(TRT_RDO_Container
 //================================================================
 TRT_RDO_Container* TRT_RDO_ContainerCnv::createTransient() {
 
-  const pool::Guid   p0_guid("5DB01CED-F6FD-4866-A1C6-E046641E44F5"); // with TRT_LoLumRawData
-  const pool::Guid   p1_guid("CFBDB7A8-C788-4EE7-A260-3C8B680234FE"); // with TRT_RDORawData
-  const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
-  const pool::Guid   TP2_guid("7138342E-0A80-4A32-A387-2842A01C2539"); // for t/p separated version with InDetRawDataContainer_p2
+  static const pool::Guid   p0_guid("5DB01CED-F6FD-4866-A1C6-E046641E44F5"); // with TRT_LoLumRawData
+  static const pool::Guid   p1_guid("CFBDB7A8-C788-4EE7-A260-3C8B680234FE"); // with TRT_RDORawData
+  static const pool::Guid   TP1_guid("DA76970C-E019-43D2-B2F9-25660DCECD9D"); // for t/p separated version with InDetRawDataContainer_p1
+  static const pool::Guid   TP2_guid("7138342E-0A80-4A32-A387-2842A01C2539"); // for t/p separated version with InDetRawDataContainer_p2
   ATH_MSG_DEBUG("createTransient(): main converter");
 
   if( compareClassGuid(TP2_guid) ) {
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p0.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p0.cxx
index 688a649ece44e924953c1215c580ce6ca588da85..acdb9f2b61b01f12a038620e7a6e1c8f1b2e258a 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p0.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p0.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 // Andrei Gaponenko <agaponenko@lbl.gov>, 2006 
@@ -17,7 +17,7 @@
 
 //================================================================
 TRT_RDO_Container* TRT_RDO_ContainerCnv_p0::createTransient(const TRT_RDO_Container_p0* persObj, MsgStream& log) {
-  std::unique_ptr<TRT_RDO_Container> trans(new TRT_RDO_Container(m_trtId->straw_layer_hash_max()));
+  std::unique_ptr<TRT_RDO_Container> trans(std::make_unique<TRT_RDO_Container>(m_trtId->straw_layer_hash_max()));
 
   MSG_DEBUG(log,"Read RDO vector, size " << persObj->size());
   
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p1.cxx
index d113b245841123614315bbc53836344f9e4f4474..017a127a34aa47d466e19814f9f16b450406c711 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/TRT_RDO_ContainerCnv_p1.cxx
@@ -125,14 +125,14 @@ void TRT_RDO_ContainerCnv_p1::persToTrans(const TRT_RDO_Container_p1* pers, TRT_
 
 //================================================================
 TRT_RDO_Container* TRT_RDO_ContainerCnv_p1::createTransient(const TRT_RDO_Container_p1* persObj, MsgStream& log) {
-    std::unique_ptr<TRT_RDO_Container> trans(new TRT_RDO_Container(m_trtId->straw_layer_hash_max()));
+    std::unique_ptr<TRT_RDO_Container> trans(std::make_unique<TRT_RDO_Container>(m_trtId->straw_layer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
 
 //================================================================
 TRT_RDO_Container_p1* TRT_RDO_ContainerCnv_p1::createPersistent(const TRT_RDO_Container* transObj, MsgStream &log) {
-  std::unique_ptr<TRT_RDO_Container_p1> pers(new TRT_RDO_Container_p1(SG::VIEW_ELEMENTS));
+  std::unique_ptr<TRT_RDO_Container_p1> pers(std::make_unique<TRT_RDO_Container_p1>(SG::VIEW_ELEMENTS));
   transToPers(transObj, pers.get(), log);
   return(pers.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/PixelClusterContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/PixelClusterContainerCnv_p1.cxx
index c7ec076acc38e3102376f7104ab90265c96a6416..03b56ee0bce912bf0258f59f9fe45ece9b46f18e 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/PixelClusterContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/PixelClusterContainerCnv_p1.cxx
@@ -147,7 +147,7 @@ InDet::PixelClusterContainer* InDet::PixelClusterContainerCnv_p1::createTransien
       log << MSG::FATAL << "PixelID helper is null in  PixelClusterContainerCnv_p1::createTransient" << endmsg;
       return nullptr;
     }
-    std::auto_ptr<InDet::PixelClusterContainer> trans(new InDet::PixelClusterContainer(m_pixId->wafer_hash_max()));
+    std::unique_ptr<InDet::PixelClusterContainer> trans(std::make_unique<InDet::PixelClusterContainer>(m_pixId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/SCT_ClusterContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/SCT_ClusterContainerCnv_p1.cxx
index 4557c9fffd8287a9b555a3a07792eeebcc07d2d0..030cb84fea297549ff952965e1f65511d599ff82 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/SCT_ClusterContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/SCT_ClusterContainerCnv_p1.cxx
@@ -152,7 +152,7 @@ InDet::SCT_ClusterContainer* InDet::SCT_ClusterContainerCnv_p1::createTransient(
       log << MSG::FATAL << "Could not initialize SCT_ClusterContainerCnv_p1 " << endmsg;
      } 
     }
-    std::auto_ptr<InDet::SCT_ClusterContainer> trans(new InDet::SCT_ClusterContainer(m_sctId->wafer_hash_max()));
+    std::unique_ptr<InDet::SCT_ClusterContainer> trans(std::make_unique<InDet::SCT_ClusterContainer>(m_sctId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/TRT_DriftCircleContainerCnv_p1.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/TRT_DriftCircleContainerCnv_p1.cxx
index b1ec20707787d3ebd578ae52a27ea03fc013a741..0a5957d4ff9e2735322b553ecdc8acd3b9ba2e14 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/TRT_DriftCircleContainerCnv_p1.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/InDetPrepRawData/TRT_DriftCircleContainerCnv_p1.cxx
@@ -146,7 +146,7 @@ InDet::TRT_DriftCircleContainer* InDet::TRT_DriftCircleContainerCnv_p1::createTr
       log << MSG::FATAL << "Could not initialize TRT_DriftCircleContainerCnv_p1 " << endmsg;
      } 
     }
-    std::auto_ptr<InDet::TRT_DriftCircleContainer> trans(new InDet::TRT_DriftCircleContainer(m_trtId->module_hash_max()));
+    std::unique_ptr<InDet::TRT_DriftCircleContainer> trans(std::make_unique<InDet::TRT_DriftCircleContainer>(m_trtId->module_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p2.cxx
index 9cbadbfe5fd4baf912d6b0059da2b2d231f52553..b6112bb9ec9e1ef12b3f045c41d6a5c8f36a3d0e 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p2.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetPrepRawData/PixelCluster.h"
@@ -170,7 +170,7 @@ InDet::PixelClusterContainer* PixelClusterContainerCnv_p2::createTransient(const
       log << MSG::FATAL << "nullptr for m_pixId in PixelClusterContainerCnv_p2::createTransient" << endmsg;
       return nullptr;
     }
-    std::auto_ptr<InDet::PixelClusterContainer> trans(new InDet::PixelClusterContainer(m_pixId->wafer_hash_max()));
+    std::unique_ptr<InDet::PixelClusterContainer> trans(std::make_unique<InDet::PixelClusterContainer>(m_pixId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p3.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p3.cxx
index f91082d4bf5a41eacef94ca84943615607784ea5..785c1afe3d91d41b0a0d0da53b22c8473587f11f 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p3.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/PixelClusterContainerCnv_p3.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetPrepRawData/PixelCluster.h"
@@ -181,7 +181,7 @@ InDet::PixelClusterContainer* PixelClusterContainerCnv_p3::createTransient(const
       log << MSG::FATAL << "nullptr for m_pixId in PixelClusterContainerCnv_p3::createTransient" << endmsg;
       return nullptr;
     }
-    std::auto_ptr<InDet::PixelClusterContainer> trans(new InDet::PixelClusterContainer(m_pixId->wafer_hash_max()));
+    std::unique_ptr<InDet::PixelClusterContainer> trans(std::make_unique<InDet::PixelClusterContainer>(m_pixId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p2.cxx
index 56a81c4e1fb8122f96fb14225572c5c6880289d4..f39e42d583b5e5a7d2b79be1d056deca773ff7c7 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p2.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetEventTPCnv/SCT_ClusterContainerCnv_p2.h"
@@ -199,7 +199,7 @@ InDet::SCT_ClusterContainer* SCT_ClusterContainerCnv_p2::createTransient(const I
       log << MSG::FATAL << "Could not initialize SCT_ClusterContainerCnv_p2 " << endmsg;
      }
     }
-    std::auto_ptr<InDet::SCT_ClusterContainer> trans(new InDet::SCT_ClusterContainer(m_sctId->wafer_hash_max()));
+    std::unique_ptr<InDet::SCT_ClusterContainer> trans(std::make_unique<InDet::SCT_ClusterContainer>(m_sctId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p3.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p3.cxx
index 322f8daef9b347d48314f07d116c8291f15e7e75..31a4b1b647fbd632f90079edb4c4c480c7e1083b 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p3.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/SCT_ClusterContainerCnv_p3.cxx
@@ -195,7 +195,7 @@ InDet::SCT_ClusterContainer* SCT_ClusterContainerCnv_p3::createTransient(const I
       log << MSG::FATAL << "Could not initialize SCT_ClusterContainerCnv_p3 " << endmsg;
      }
     }
-    std::auto_ptr<InDet::SCT_ClusterContainer> trans(new InDet::SCT_ClusterContainer(m_sctId->wafer_hash_max()));
+    std::unique_ptr<InDet::SCT_ClusterContainer> trans(std::make_unique<InDet::SCT_ClusterContainer>(m_sctId->wafer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/TRT_DriftCircleContainerCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/TRT_DriftCircleContainerCnv_p2.cxx
index 80e4bd0e7c524fab6198de0af639af1b031c4ebf..1d684d6e2052f346c75fc5ef3451fa329d0073c4 100644
--- a/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/TRT_DriftCircleContainerCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventTPCnv/src/TRT_DriftCircleContainerCnv_p2.cxx
@@ -197,7 +197,7 @@ InDet::TRT_DriftCircleContainer* TRT_DriftCircleContainerCnv_p2::createTransient
       return nullptr; // if m_trtId not initialized return null pointer instead of dereferencing it later
      }
     }
-    std::auto_ptr<InDet::TRT_DriftCircleContainer> trans(new InDet::TRT_DriftCircleContainer(m_trtId->straw_layer_hash_max()));
+    std::unique_ptr<InDet::TRT_DriftCircleContainer> trans(std::make_unique<InDet::TRT_DriftCircleContainer>(m_trtId->straw_layer_hash_max()));
     persToTrans(persObj, trans.get(), log);
     return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/SiHitCollectionCnv.cxx b/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/SiHitCollectionCnv.cxx
index cc63c6766c97aecd8bae0a613f7bdf78eac6b4f7..4359f4328ed523bda72ee56985f4db06111d481a 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/SiHitCollectionCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/SiHitCollectionCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEventTPCnv/InDetHits/SiHitCollectionCnv_p1.h"
@@ -31,15 +31,15 @@ SiHitCollection* SiHitCollectionCnv::createTransient() {
 
     SiHitCollection       *trans_cont(0);
     if( this->compareClassGuid(p3_guid)) {
-      std::auto_ptr< SiHitCollection_p3 >   col_vect( this->poolReadObject< SiHitCollection_p3 >() );
+      std::unique_ptr< SiHitCollection_p3 >   col_vect( this->poolReadObject< SiHitCollection_p3 >() );
       trans_cont = converter_p3.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p1_guid)) {
-      std::auto_ptr< SiHitCollection_p1 >   col_vect( this->poolReadObject< SiHitCollection_p1 >() );
+      std::unique_ptr< SiHitCollection_p1 >   col_vect( this->poolReadObject< SiHitCollection_p1 >() );
       trans_cont = converter_p1.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p2_guid)) { // version p2
-      std::auto_ptr< SiHitCollection_p2 >   col_vect( this->poolReadObject< SiHitCollection_p2 >() );
+      std::unique_ptr< SiHitCollection_p2 >   col_vect( this->poolReadObject< SiHitCollection_p2 >() );
       trans_cont = converter_p2.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(old_guid)) {
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/TRTUncompressedHitCollectionCnv.cxx b/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/TRTUncompressedHitCollectionCnv.cxx
index 192a2cf483926d479bbfa3dbf8d14c8daadcc7a0..302922715d364b8db119520aa5f902d17fb6db00 100755
--- a/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/TRTUncompressedHitCollectionCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventAthenaPool/src/TRTUncompressedHitCollectionCnv.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEventTPCnv/InDetHits/TRT_HitCollectionCnv_p1.h"
@@ -34,19 +34,19 @@ TRTUncompressedHitCollection* TRTUncompressedHitCollectionCnv::createTransient()
 
     TRTUncompressedHitCollection       *trans_cont(0);
     if( this->compareClassGuid(p4_guid)) {
-        std::auto_ptr< TRT_HitCollection_p4 >   col_vect( this->poolReadObject< TRT_HitCollection_p4 >() );
+        std::unique_ptr< TRT_HitCollection_p4 >   col_vect( this->poolReadObject< TRT_HitCollection_p4 >() );
         trans_cont = converter_p4.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p1_guid)) {
-        std::auto_ptr< TRT_HitCollection_p1 >   col_vect( this->poolReadObject< TRT_HitCollection_p1 >() );
+        std::unique_ptr< TRT_HitCollection_p1 >   col_vect( this->poolReadObject< TRT_HitCollection_p1 >() );
         trans_cont = converter_p1.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p2_guid)) {
-        std::auto_ptr< TRT_HitCollection_p2 >   col_vect( this->poolReadObject< TRT_HitCollection_p2 >() );
+        std::unique_ptr< TRT_HitCollection_p2 >   col_vect( this->poolReadObject< TRT_HitCollection_p2 >() );
         trans_cont = converter_p2.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(p3_guid)) {
-        std::auto_ptr< TRT_HitCollection_p3 >   col_vect( this->poolReadObject< TRT_HitCollection_p3 >() );
+        std::unique_ptr< TRT_HitCollection_p3 >   col_vect( this->poolReadObject< TRT_HitCollection_p3 >() );
         trans_cont = converter_p3.createTransient( col_vect.get(), mlog );
     }
     else if( this->compareClassGuid(old_guid)) {
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p2.cxx
index c490af1bddbe59f03586c8ed14fe063f85e02a5b..428a76f6d624024e893dd9cf7cac83aaf5642cda 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p2.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEvent/SiHit.h"
@@ -241,7 +241,7 @@ void SiHitCollectionCnv_p2::transToPers(const SiHitCollection* transCont, SiHitC
 
 
 SiHitCollection* SiHitCollectionCnv_p2::createTransient(const SiHitCollection_p2* persObj, MsgStream &log) {
-  std::auto_ptr<SiHitCollection> trans(new SiHitCollection("DefaultCollectionName",persObj->m_nHits.size()));
+  std::unique_ptr<SiHitCollection> trans(std::make_unique<SiHitCollection>("DefaultCollectionName",persObj->m_nHits.size()));
   persToTrans(persObj, trans.get(), log);
   return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p3.cxx b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p3.cxx
index 2d2104f6f8d6d7aac6d26f3d16dbbbbbb067ed03..b9dfee674d6e6ddd1b5d815ed55b0cc09b097bf9 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p3.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/SiHitCollectionCnv_p3.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEvent/SiHit.h"
@@ -242,7 +242,7 @@ void SiHitCollectionCnv_p3::transToPers(const SiHitCollection* transCont, SiHitC
 
 
 SiHitCollection* SiHitCollectionCnv_p3::createTransient(const SiHitCollection_p3* persObj, MsgStream &log) {
-  std::auto_ptr<SiHitCollection> trans(new SiHitCollection("DefaultCollectionName",persObj->m_nHits.size()));
+  std::unique_ptr<SiHitCollection> trans(std::make_unique<SiHitCollection>("DefaultCollectionName",persObj->m_nHits.size()));
   persToTrans(persObj, trans.get(), log);
   return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p2.cxx b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p2.cxx
index ea39ab3fc3d28f6d61735ce4b1fb6cc91cf0fd62..698a39312cc81231cc37b69a3aeeba96d2bfc11d 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p2.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p2.cxx
@@ -120,7 +120,7 @@ void TRT_HitCollectionCnv_p2::transToPers(const TRTUncompressedHitCollection* tr
 
 
 TRTUncompressedHitCollection* TRT_HitCollectionCnv_p2::createTransient(const TRT_HitCollection_p2* persObj, MsgStream &log) {
-  std::auto_ptr<TRTUncompressedHitCollection> trans(new TRTUncompressedHitCollection("DefaultCollectionName",persObj->m_nHits.size()));
+  std::unique_ptr<TRTUncompressedHitCollection> trans(std::make_unique<TRTUncompressedHitCollection>("DefaultCollectionName",persObj->m_nHits.size()));
   persToTrans(persObj, trans.get(), log);
   return(trans.release());
 }
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p3.cxx b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p3.cxx
index ddc687f73e1a0ac81ccd5145558b18bde0e9dc98..d4ade6a9d18ae4cc94cd931bd7a763ddfa1fa4b7 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p3.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p3.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEvent/TRTUncompressedHit.h"
@@ -278,7 +278,7 @@ void TRT_HitCollectionCnv_p3::transToPers(const TRTUncompressedHitCollection* tr
 
 // Create Transient
 TRTUncompressedHitCollection* TRT_HitCollectionCnv_p3::createTransient(const TRT_HitCollection_p3* persObj, MsgStream &log) {
-  std::auto_ptr<TRTUncompressedHitCollection> trans(new TRTUncompressedHitCollection("DefaultCollectionName",persObj->m_nHits.size()));
+  std::unique_ptr<TRTUncompressedHitCollection> trans(std::make_unique<TRTUncompressedHitCollection>("DefaultCollectionName",persObj->m_nHits.size()));
   persToTrans(persObj, trans.get(), log);
   return(trans.release());
 } //createTransient
diff --git a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p4.cxx b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p4.cxx
index 7b0b97f870656420457e4d523ea0a55c3b5e1c62..b9f85c1043db021f2654f455032ad3643bd608d8 100644
--- a/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p4.cxx
+++ b/InnerDetector/InDetEventCnv/InDetSimEventTPCnv/src/InDetHits/TRT_HitCollectionCnv_p4.cxx
@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 */
 
 #include "InDetSimEvent/TRTUncompressedHit.h"
@@ -281,7 +281,7 @@ void TRT_HitCollectionCnv_p4::transToPers(const TRTUncompressedHitCollection* tr
 
 // Create Transient
 TRTUncompressedHitCollection* TRT_HitCollectionCnv_p4::createTransient(const TRT_HitCollection_p4* persObj, MsgStream &log) {
-  std::auto_ptr<TRTUncompressedHitCollection> trans(new TRTUncompressedHitCollection("DefaultCollectionName",persObj->m_nHits.size()));
+  std::unique_ptr<TRTUncompressedHitCollection> trans(std::make_unique<TRTUncompressedHitCollection>("DefaultCollectionName",persObj->m_nHits.size()));
   persToTrans(persObj, trans.get(), log);
   return(trans.release());
 } //createTransient
diff --git a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_FlaggedCondDataCnv.cxx b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_FlaggedCondDataCnv.cxx
index 299160dca6baac013784be1836b545ae5542ebfc..d8a56f96bc0c49b1154399ea7c1f0e10433871c9 100644
--- a/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_FlaggedCondDataCnv.cxx
+++ b/InnerDetector/InDetEventCnv/InDetEventAthenaPool/src/SCT_FlaggedCondDataCnv.cxx
@@ -24,10 +24,10 @@ SCT_FlaggedCondDataCnv::createPersistent(SCT_FlaggedCondData* transCont) {
 SCT_FlaggedCondData*
 SCT_FlaggedCondDataCnv::createTransient() {
   MsgStream log(msgSvc(), "SCT_FlaggedCondDataCnv");
-  const pool::Guid p1_guid("0C10E502-F02B-440B-9E8F-6A8C31915D7C");
+  static const pool::Guid p1_guid("0C10E502-F02B-440B-9E8F-6A8C31915D7C");
   if (compareClassGuid(p1_guid)) {
-    /** using auto_ptr ensures deletion of the persistent object */
-    std::auto_ptr<SCT_FlaggedCondData_p1> col_vect( poolReadObject< SCT_FlaggedCondData_p1 >() );
+    /** using unique_ptr ensures deletion of the persistent object */
+    std::unique_ptr<SCT_FlaggedCondData_p1> col_vect( poolReadObject< SCT_FlaggedCondData_p1 >() );
     SCT_FlaggedCondDataCnv_p1 cnv;
     std::unique_ptr<SCT_FlaggedCondData> trasnObj = std::make_unique<SCT_FlaggedCondData>();
     cnv.persToTrans(col_vect.get(), trasnObj.get(), log);